@@ -2,8 +2,8 @@
     N = 5
     H = num(N)
     a = destroy(N)
-    A_op = a+a'
-    spectra(x) = (x>0) * 0.5
+    A_op = a + a'
+    spectra(x) = (x > 0) * 0.5
     for sec_cutoff in [0, 0.1, 1, 3, -1]
         R = bloch_redfield_tensor(H, ((A_op, spectra),), [a^2], sec_cutoff = sec_cutoff, fock_basis = Val(true))
         R_eig, evecs =
@@ -15,29 +15,29 @@
         state = rand_dm(N) |> mat2vec
         fock_computed = R * state
         eig_computed = (sprepost(evecs, evecs') * R_eig * sprepost(evecs', evecs)) * state
-        @test isapprox(fock_computed, eig_computed, atol = 1e-15)
+        @test isapprox(fock_computed, eig_computed, atol = 1.0e-15)
     end
 end
 
 @testitem "Compare brterm and Lindblad" begin
     N = 5
     H = num(N)
-    a = destroy(N) + destroy(N)^2/2
-    A_op = a+a'
-    spectra(x) = x>0
+    a = destroy(N) + destroy(N)^2 / 2
+    A_op = a + a'
+    spectra(x) = x > 0
 
     # this test applies for limited cutoff
     lindblad = lindblad_dissipator(a)
     computation = brterm(H, A_op, spectra, sec_cutoff = 1.5, fock_basis = Val(true))
-    @test isapprox(lindblad, computation, atol = 1e-15)
+    @test isapprox(lindblad, computation, atol = 1.0e-15)
 end
 
 @testitem "brterm basis" begin
     N = 5
     H = num(N)
-    a = destroy(N) + destroy(N)^2/2
-    A_op = a+a'
-    spectra(x) = x>0
+    a = destroy(N) + destroy(N)^2 / 2
+    A_op = a + a'
+    spectra(x) = x > 0
     for sec_cutoff in [0, 0.1, 1, 3, -1]
         R = brterm(H, A_op, spectra, sec_cutoff = sec_cutoff, fock_basis = Val(true))
         R_eig, evecs = brterm(H, A_op, spectra, sec_cutoff = sec_cutoff, fock_basis = Val(false))
@@ -48,12 +48,12 @@ end
         state = rand_dm(N) |> mat2vec
         fock_computed = R * state
         eig_computed = (sprepost(evecs, evecs') * R_eig * sprepost(evecs', evecs)) * state
-        @test isapprox(fock_computed, eig_computed, atol = 1e-15)
-    end;
+        @test isapprox(fock_computed, eig_computed, atol = 1.0e-15)
+    end
 end
 
 @testitem "brterm sprectra function" begin
-    f(x) = exp(x)/10
+    f(x) = exp(x) / 10
     function g(x)
         nbar = n_thermal(abs(x), 1)
         if x > 0
@@ -66,7 +66,7 @@ end
     end
 
     spectra_list = [
-        x -> (x>0),  # positive frequency filter
+        x -> (x > 0),  # positive frequency filter
         x -> one(x), # no filter
         f, # smooth filter
         g, # thermal field
@@ -74,8 +74,8 @@ end
 
     N = 5
     H = num(N)
-    a = destroy(N) + destroy(N)^2/2
-    A_op = a+a'
+    a = destroy(N) + destroy(N)^2 / 2
+    A_op = a + a'
     for spectra in spectra_list
         R = brterm(H, A_op, spectra, sec_cutoff = 0.1, fock_basis = Val(true))
         R_eig, evecs = brterm(H, A_op, spectra, sec_cutoff = 0.1, fock_basis = Val(false))
@@ -86,14 +86,14 @@ end
         state = rand_dm(N) |> mat2vec
         fock_computed = R * state
         eig_computed = (sprepost(evecs, evecs') * R_eig * sprepost(evecs', evecs)) * state
-        @test isapprox(fock_computed, eig_computed, atol = 1e-15)
+        @test isapprox(fock_computed, eig_computed, atol = 1.0e-15)
     end
 end
 
 @testitem "simple qubit system" begin
     pauli_vectors = [sigmax(), sigmay(), sigmaz()]
     γ = 0.25
-    spectra(x) = γ * (x>=0)
+    spectra(x) = γ * (x >= 0)
     _m_c_op = √γ * sigmam()
     _z_c_op = √γ * sigmaz()
     _x_a_op = (sigmax(), spectra)
