@@ -11,7 +11,7 @@
     M = latt.N + 1       # Number of states in the LR basis
 
     # Define initial state
-    ϕ = Vector{QuantumObject{Ket,Dimensions{M - 1,NTuple{M - 1,Space}},Vector{ComplexF64}}}(undef, M)
+    ϕ = Vector{QuantumObject{Ket, Dimensions{M - 1, NTuple{M - 1, Space}}, Vector{ComplexF64}}}(undef, M)
     ϕ[1] = kron(fill(basis(2, 1), N_modes)...)
 
     i = 1
@@ -19,13 +19,13 @@
         global i += 1
         i <= M && (ϕ[i] = multisite_operator(latt, j => sigmap()) * ϕ[1])
     end
-    for k in 1:(N_modes-1)
-        for l in (k+1):N_modes
+    for k in 1:(N_modes - 1)
+        for l in (k + 1):N_modes
             global i += 1
             i <= M && (ϕ[i] = multisite_operator(latt, k => sigmap(), l => sigmap()) * ϕ[1])
         end
     end
-    for i in (i+1):M
+    for i in (i + 1):M
         ϕ[i] = QuantumObject(rand(ComplexF64, size(ϕ[1])[1]), dims = ϕ[1].dims)
         normalize!(ϕ[i])
     end
@@ -73,15 +73,15 @@
         return entropy_vn(Qobj(Hermitian(σ), type = Operator()), base = 2)
     end
 
-    opt = (err_max = 1e-3, p0 = 0.0, atol_inv = 1e-6, adj_condition = "variational", Δt = 0.0, progress = false)
+    opt = (err_max = 1.0e-3, p0 = 0.0, atol_inv = 1.0e-6, adj_condition = "variational", Δt = 0.0, progress = false)
 
     sol_lr = lr_mesolve(H, z, B, tl, c_ops; e_ops = e_ops, f_ops = (f_entropy,), opt = opt)
 
     # Test
     S_lr = real(sol_lr.fexpect[1, end]) / latt.N
 
-    @test real(sol_me.expect[1, :]) ≈ real(sol_lr.expect[1, :]) atol = 1e-1
-    @test S_lr ≈ Strue atol = 1e-1
+    @test real(sol_me.expect[1, :]) ≈ real(sol_lr.expect[1, :]) atol = 1.0e-1
+    @test S_lr ≈ Strue atol = 1.0e-1
 
     @test_logs (:warn,) MultiSiteOperator(latt, 1 => sigmax()) # deprecated warning
 end
