@@ -5,19 +5,19 @@
     QuantumToolbox.cite(io_buffer)
     captured_output = String(take!(io_buffer))
     @test captured_output ==
-          """@article{QuantumToolbox.jl2025,\n""" *
-          """  title = {Quantum{T}oolbox.jl: {A}n efficient {J}ulia framework for simulating open quantum systems},\n""" *
-          """  author = {Mercurio, Alberto and Huang, Yi-Te and Cai, Li-Xun and Chen, Yueh-Nan and Savona, Vincenzo and Nori, Franco},\n""" *
-          """  journal = {{Quantum}},\n""" *
-          """  issn = {2521-327X},\n""" *
-          """  publisher = {{Verein zur F{\\"{o}}rderung des Open Access Publizierens in den Quantenwissenschaften}},\n""" *
-          """  volume = {9},\n""" *
-          """  pages = {1866},\n""" *
-          """  month = sep,\n""" *
-          """  year = {2025},\n""" *
-          """  doi = {10.22331/q-2025-09-29-1866},\n""" *
-          """  url = {https://doi.org/10.22331/q-2025-09-29-1866}\n""" *
-          """}\n"""
+        """@article{QuantumToolbox.jl2025,\n""" *
+        """  title = {Quantum{T}oolbox.jl: {A}n efficient {J}ulia framework for simulating open quantum systems},\n""" *
+        """  author = {Mercurio, Alberto and Huang, Yi-Te and Cai, Li-Xun and Chen, Yueh-Nan and Savona, Vincenzo and Nori, Franco},\n""" *
+        """  journal = {{Quantum}},\n""" *
+        """  issn = {2521-327X},\n""" *
+        """  publisher = {{Verein zur F{\\"{o}}rderung des Open Access Publizierens in den Quantenwissenschaften}},\n""" *
+        """  volume = {9},\n""" *
+        """  pages = {1866},\n""" *
+        """  month = sep,\n""" *
+        """  year = {2025},\n""" *
+        """  doi = {10.22331/q-2025-09-29-1866},\n""" *
+        """  url = {https://doi.org/10.22331/q-2025-09-29-1866}\n""" *
+        """}\n"""
 
     @testset "n_thermal" begin
         ω1 = rand(Float64)
@@ -42,7 +42,7 @@
         ϵ0 = PhysicalConstants.ϵ0
 
         @test h / ħ ≈ 2 * π
-        @test μ0 / (4e-7 * π) ≈ 1.0
+        @test μ0 / (4.0e-7 * π) ≈ 1.0
         @test c^2 * μ0 * ϵ0 ≈ 1.0
     end
 
